@@ -61,8 +61,8 @@ class DraftListing(BaseModel):
     personalization_is_required: Optional[bool]
     personalization_char_count_max: Optional[int]
     personalization_instructions: Optional[int]
-    production_partner_ids: List[int]
-    image_ids: List[int]
+    production_partner_ids: Optional[List[int]]
+    image_ids: Optional[List[int]]
     is_supply: bool
     is_customizable: bool
     should_auto_renew: bool
