@@ -29,7 +29,7 @@ class ListingResource:
         json = self.session.request(endpoint, params={"includes":includes})
         return Listing(**json)
 
-    def find_all_active_listings(self, limit=25, offset=0, keywords="", sort_on="created", sort_order="desc", min_price=None, max_price=None, taxonomy_id=None, shop_location="US"):
+    def find_all_active_listings(self, limit=25, offset=0, keywords="", sort_on="created", sort_order="desc", min_price=None, max_price=None, taxonomy_id=None, shop_location="United States"):
         """
         Find All Active Listings By Keywords, Min price, Max Price Or Shop Location
 
