@@ -14,24 +14,32 @@ class EtsySession:
     def __init__(self,
                  client_key: str,
                  client_secret: str,
-                 token: dict,
+                 token: Optional[dict] = None,
                  token_updater: Optional[Callable] = None
                  ):
 
-        if token_updater is None:
-            self.token_updater = self.__token_updater
-        else:
-            self.token_updater = token_updater
+        
 
         self.CLIENT_KEY = client_key
         self.CLIENT_SECRET = client_secret
-        self.TOKEN = token
-        self.__refresh_url = "https://api.etsy.com/v3/public/oauth/token"
         self.__base_endpoint = "https://openapi.etsy.com/v3/application/"
+        self.__oauth2_session = None
+        
+        if token is not None:
+            if token_updater is None:
+                self.token_updater = self.__token_updater
+            else:
+                self.token_updater = token_updater
+            self.TOKEN = token
+            
+            self.__refresh_url = "https://api.etsy.com/v3/public/oauth/token"
+            self.__oauth2_session = self.__create_oath2_session()
+            self.__me = Me(**self.request(f"users/me"))
 
-        self.__oauth2_session = self.__create_oath2_session()
-        self.__me = Me(**self.request(f"users/me"))
-
+        else:
+            self.__oauth2_session = requests.Session()
+            
+        
     def __create_oath2_session(self) -> OAuth2Session:
         refresh_kwargs = {
             'client_id': self.CLIENT_KEY,
